#include <QtCore/QTimer>
#include <QtGui/QStandardItemModel>
#include <QtQml/QQmlApplicationEngine>
#include <QtRemoteObjects/QRemoteObjectHost>
#include <QtWidgets/QApplication>
#include <QtWidgets/QListView>



class RemoveTimer : public QTimer {
	QPointer<QAbstractItemModel> model;

public:
	explicit RemoveTimer(QAbstractItemModel* m, QObject* p = nullptr)
		: QTimer(p), model(m) {
		callOnTimeout(this, &RemoveTimer::removeTop);
	};

	void removeTop() {
		if (model) if (model->rowCount()) {
			model->removeRow(0);
		};
	};
};



int main(int argc, char* argv[]) {
	QApplication app(argc, argv);

	QStandardItemModel model;
	for (int n = 0; n < 1000; n++) {
		QStandardItem* item = new QStandardItem(QString("Item-%1").arg(n));
		item->setToolTip(QString("Description of item %1").arg(n));
		model.appendRow(item);
	};
	model.setItemRoleNames(QHash<int, QByteArray>{
		{Qt::DisplayRole, QByteArrayLiteral("title")},
		{Qt::ToolTipRole, QByteArrayLiteral("description")},
	});

	QRemoteObjectHost host(QStringLiteral("tcp://0.0.0.0:55555"));
	host.enableRemoting(&model, "MyModel", QVector<int>{
		Qt::DisplayRole,
		Qt::ToolTipRole,
	});

	QListView view;
	view.setModel(&model);
	view.show();

	RemoveTimer	timer(&model);
	timer.start(100);

	return app.exec();
};


